[![travis-ci-build](https://travis-ci.org/chudur-budur/pviz.svg?branch=master)](https://travis-ci.org/github/chudur-budur/pviz)
[![GitHub Pipenv locked Python version](https://img.shields.io/github/pipenv/locked/python-version/chudur-budur/pviz)](https://www.python.org/downloads/release/python-380/)
[![license](https://img.shields.io/github/license/chudur-budur/pviz)](https://www.apache.org/licenses/LICENSE-2.0)
# pviz
### A Framework for High-dimensional (3 <= m <= 10) Pareto-optimal Front Visualization and Analytics
